@@ -31,8 +31,9 @@
  * Note - The textures in animations are only
  *        displayed from the first frame.
  */
-
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE /* for strndup */
+#endif
 
 #include <errno.h>
 #include <pthread.h>
@@ -83,7 +84,10 @@ findPath (char *object,
   				 sizeof (char) *
 				 (strlen (filePath) + strlen (file) + 1));
     if (!filePath)
+    {
+	free (filePath);
 	return NULL;
+    }
 
     strcat (filePath, file);
 
@@ -406,13 +410,13 @@ CubemodelScreen::loadMaterials (CubemodelObject *data,
 
 		memcpy (tmpTexList, data->tex, sizeof (GLTexture::List) *
 						data->nTex);
-		
+
 		delete[] data->tex;
-		
+
 		data->tex = new GLTexture::List[newTexSize];
-		
+
 		memcpy (data->tex, tmpTexList, data->nTex);
-		
+
 		data->texWidth = (unsigned int *) realloc (data->texWidth,
 		                          sizeof (unsigned int) *
 		                          (data->nTex + 1));
@@ -430,7 +434,7 @@ CubemodelScreen::loadMaterials (CubemodelObject *data,
 	    {
 		tmpName = findPath (approxPath, tmpPtr[0]);
 		CompString texTmpName = CompString (tmpName);
-		CompSize currentMaterialSize = 
+		CompSize currentMaterialSize =
 					       CompSize (currentMaterial->width,
 						       currentMaterial->height);
 		data->tex[data->nTex] =
@@ -1632,10 +1636,8 @@ CubemodelScreen::drawVBOModel (CubemodelObject *data,
 
     int prevMaterialIndex = -1;
 
-    int ambientTextureIndex     = -1;
-    int diffuseTextureIndex     = -1;
-    int specularTextureIndex    = -1;
     int transparentTextureIndex = -1;
+    int diffuseTextureIndex     = -1;
 
     const float *ambient   = white;
     const float *diffuse   = white;
@@ -1683,12 +1685,8 @@ CubemodelScreen::drawVBOModel (CubemodelObject *data,
 	    {
 		glDisable (GL_COLOR_MATERIAL);
 
-		ambientTextureIndex     =
-		    data->material[0][group->materialIndex].map_Ka;
 		diffuseTextureIndex     =
 		    data->material[0][group->materialIndex].map_Kd;
-		specularTextureIndex    =
-		    data->material[0][group->materialIndex].map_Ks;
 		transparentTextureIndex =
 		    data->material[0][group->materialIndex].map_d;
 
