@@ -406,7 +406,7 @@ PrivateElementScreen::switchTimeout ()
 	if (!text->eTextures.empty ())
 	{
 	    text->nTexture = 
-		++text->nTexture %
+		(text->nTexture + 1) %
 		    (text->eTextures.size ());
 	}
     }
